AddressingFields

Struct AddressingFields 

pub struct AddressingFields<T: AsRef<[u8]>, FC: AsRef<[u8]>> { /* private fields */ }
A reader/writer for the IEEE 802.15.4 Addressing Fields.

Implementations

Source

impl<T: AsRef<[u8]>, FC: AsRef<[u8]>> AddressingFields<T, FC>

pub fn new(buffer: T, fc: FrameControl<FC>) -> Result<Self>

Create a new AddressingFields reader/writer from a given buffer.

Errors

This function will check the length of the buffer to ensure it is large enough to contain the addressing fields. If the buffer is too small, an error will be returned.

pub fn new_unchecked(buffer: T, fc: FrameControl<FC>) -> Self

Create a new AddressingFields reader/writer from a given buffer without checking the length.

pub fn len(&self) -> usize

Return the length of the Addressing Fields in octets.

pub fn dst_address(&self) -> Option<Address>

Return the IEEE 802.15.4 destination Address if not absent.

pub fn src_address(&self) -> Option<Address>

Return the IEEE 802.15.4 source Address if not absent.

pub fn dst_pan_id(&self) -> Option<u16>

Return the IEEE 802.15.4 destination PAN ID if not elided.

pub fn src_pan_id(&self) -> Option<u16>

Return the IEEE 802.15.4 source PAN ID if not elided.

Source

impl<T: AsRef<[u8]> + AsMut<[u8]>, FC: AsRef<[u8]>> AddressingFields<T, FC>

pub fn write_fields(&mut self, fields: &AddressingFieldsRepr)

Write the addressing fields to the buffer.