pub struct ChannelHoppingRepr {
pub hopping_sequence_id: u8,
}Expand description
A high-level representation of a Channel Hopping Nested Information Element.
Fields
hopping_sequence_id: u8The hopping sequence ID.
Implementations
Sourceimpl ChannelHoppingRepr
impl ChannelHoppingRepr
Sourcepub fn parse(ie: &ChannelHopping<&[u8]>) -> Self
pub fn parse(ie: &ChannelHopping<&[u8]>) -> Self
Parse a Channel Hopping Information Element.
Sourcepub fn buffer_len(&self) -> usize
pub fn buffer_len(&self) -> usize
The buffer length required to emit the Channel Hopping Information Element.
Sourcepub fn emit(&self, ie: &mut ChannelHopping<&mut [u8]>)
pub fn emit(&self, ie: &mut ChannelHopping<&mut [u8]>)
Emit the Channel Hopping Information Element into a buffer.