FrameControl

Struct FrameControl 

pub struct FrameControl<T: AsRef<[u8]>> { /* private fields */ }
A reader/writer for the IEEE 802.15.4 Frame Control field.

Implementations

Source

impl<T: AsRef<[u8]>> FrameControl<T>

pub fn new(buffer: T) -> Result<Self>

Create a new FrameControl reader/writer from a given buffer.

Errors

Returns an error if the buffer is too short.

pub fn new_unchecked(buffer: T) -> Self

Create a new FrameControl reader/writer from a given buffer without length checking.

pub fn into_inner(self) -> T

Return the inner buffer.

pub fn frame_type(&self) -> FrameType

Return the FrameType field.

pub fn security_enabled(&self) -> bool

Returns true when the security enabled field is set.

pub fn frame_pending(&self) -> bool

Returns true when the frame pending field is set.

pub fn ack_request(&self) -> bool

Returns true when the acknowledgement request field is set.

pub fn pan_id_compression(&self) -> bool

Returns true when the PAN ID compression field is set.

pub fn sequence_number_suppression(&self) -> bool

Returns true when the sequence number suppression field is set.

pub fn information_elements_present(&self) -> bool

Returns true when the information element field is set.

pub fn dst_addressing_mode(&self) -> AddressingMode

Return the Destination AddressingMode.

pub fn src_addressing_mode(&self) -> AddressingMode

Return the Source AddressingMode.

pub fn frame_version(&self) -> FrameVersion

Return the FrameVersion.

Source

impl<T: AsRef<[u8]> + AsMut<[u8]>> FrameControl<T>

pub fn set_frame_type(&mut self, frame_type: FrameType)

Set the frame type field.

pub fn set_security_enabled(&mut self, security_enabled: bool)

Set the security enabled field.

pub fn set_frame_pending(&mut self, frame_pending: bool)

Set the frame pending field.

pub fn set_ack_request(&mut self, ack_request: bool)

Set the acknowledgement request field.

pub fn set_pan_id_compression(&mut self, pan_id_compression: bool)

Set the PAN ID compression field.

pub fn set_sequence_number_suppression( &mut self, sequence_number_suppression: bool, )

Set the sequence number suppression field.

pub fn set_information_elements_present( &mut self, information_elements_present: bool, )

Set the information element present field.

pub fn set_dst_addressing_mode(&mut self, addressing_mode: AddressingMode)

Set the destination addressing mode field.

pub fn set_src_addressing_mode(&mut self, addressing_mode: AddressingMode)

Set the source addressing mode field.

pub fn set_frame_version(&mut self, frame_version: FrameVersion)

Set the frame version field.