pub struct SupportedFrequencyBands(/* private fields */);Expand description
Supported Frequency Bands values.
Implementations
Sourceimpl SupportedFrequencyBands
impl SupportedFrequencyBands
Sourcepub const BAND_161_MHZ: Self
pub const BAND_161_MHZ: Self
169 MHz band.
Sourcepub const BAND_216_MHZ: Self
pub const BAND_216_MHZ: Self
216 MHz band.
Sourcepub const BAND_217_MHZ: Self
pub const BAND_217_MHZ: Self
217 MHz band.
Sourcepub const BAND_220_MHZ: Self
pub const BAND_220_MHZ: Self
220 MHz band.
Sourcepub const BAND_450_MHZ: Self
pub const BAND_450_MHZ: Self
450 MHz band.
Sourcepub const BAND_779_MHZ: Self
pub const BAND_779_MHZ: Self
779 MHz band.
Sourcepub const BAND_800_MHZ: Self
pub const BAND_800_MHZ: Self
800 MHz band.
Sourcepub const BAND_806_MHZ: Self
pub const BAND_806_MHZ: Self
806 MHz band.
Sourcepub const BAND_896_MHZ: Self
pub const BAND_896_MHZ: Self
896 MHz band.
Sourcepub const BAND_915_MHZ: Self
pub const BAND_915_MHZ: Self
915 MHz band.
Sourcepub const BAND_928_MHZ: Self
pub const BAND_928_MHZ: Self
928 MHz band.
Sourcepub const BAND_2450_MHZ: Self
pub const BAND_2450_MHZ: Self
2450 MHz band.
Sourcepub const BAND_4965_MHZ: Self
pub const BAND_4965_MHZ: Self
4965 MHz band.
Sourcepub const BAND_5800_MHZ: Self
pub const BAND_5800_MHZ: Self
5800 MHz band.
Sourcepub const BAND_RESERVED: Self
pub const BAND_RESERVED: Self
Reserved.
Sourceimpl SupportedFrequencyBands
impl SupportedFrequencyBands
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SupportedFrequencyBands
impl SupportedFrequencyBands
Sourcepub const fn iter(&self) -> Iter<SupportedFrequencyBands>
pub const fn iter(&self) -> Iter<SupportedFrequencyBands>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SupportedFrequencyBands>
pub const fn iter_names(&self) -> IterNames<SupportedFrequencyBands>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.